@@ -9,13 +9,17 @@ subroutine wrtout(unit,message,paral)
   character(len=500),intent(inout) :: message
   character(len=4),intent(in) :: paral
 
-  write(unit, *) "[AB] ", trim(message)
+  if (unit == ab_out) then
+     write(unit, *) "[AB] ", trim(paral), " - ", trim(message)
+  end if
 end subroutine wrtout
 
 subroutine leave_new()
 
   implicit none
 
+  write(0, *) "Sorry, I'm dead."
+  write(0, *) "R.I.P."
   stop
 end subroutine leave_new
 
@@ -32,4 +36,6 @@ subroutine timab(nn,option,tottim)
   !arrays
   real(dp),intent(out) :: tottim(2)
 
+  tottim = real((/nn, option /), dp)
 end subroutine timab
+
