@@ -51,27 +51,44 @@ class MolecularDynamicFile:
                   stats = os.stat(files)
                   fic_tuple = time.localtime(stats[8]), files
                   lili = string.split(files, '.')
-                  if files.find('_OUT.nc') == len(files)-7 and len(files)>7 :
+#                  if files.find('_OUT.nc') == len(files)-7 and len(files)>7 :
+#                      OUT_list.append(fic_tuple)
+                  if files.find('HIST.nc') == len(files)-7 and len(files)>7 :
+                      OUT_list.append(fic_tuple)
+                  if files.find('HIST.nc') == len(files)-7 and len(files)>7 :
                       OUT_list.append(fic_tuple)
               if len(OUT_list) > 0 :
                   OUT_list.sort() ; OUT_list.reverse()
                   fic_HIST=OUT_list[0][1].replace('_OUT.nc','_HIST')
+                  fic_HIST=OUT_list[0][1]
                   if os.path.exists(fic_HIST) :
                       self.namefile1 = fic_HIST
-                      self.namefile2 = fic_HIST.replace('_HIST','_OUT.nc')
+                      self.namefile2 = fic_HIST
+#                      self.namefile2 = fic_HIST.replace('_HIST','_OUT.nc')
                       self.type_of_file = 'netcdf'
       # or the file in parameter :
       else:
           if str(pnamefile).find('_OUT.nc') != -1:  
               self.namefile2 = str(pnamefile)
-              self.namefile1 = str(pnamefile).replace('_OUT.nc','_HIST')
+              self.namefile1 = str(pnamefile).replace('_OUT.nc','_HIST')              
+              self.type_of_file = 'netcdf'
+          elif str(pnamefile).find('HIST.nc') != -1 :
+              self.namefile1 = str(pnamefile)
+              if(os.path.exists(self.namefile1.replace('HIST.nc','OUT.nc'))):
+                  self.namefile2 = str(pnamefile).replace('HIST.nc','OUT.nc')
+              else:
+                  self.namefile2 = str(pnamefile)
               self.type_of_file = 'netcdf'
 
-          elif str(pnamefile).find('HIST') != -1 :
-              self.namefile2 = str(pnamefile).replace('_HIST','_OUT.nc')
               self.namefile1 = str(pnamefile)
               self.type_of_file = 'netcdf'
-
+          elif str(pnamefile).find('HIST') != -1 :
+              self.namefile1 = str(pnamefile)
+              if(os.path.exists(self.namefile1.replace('HIST','OUT.nc'))):
+                  self.namefile2 = str(pnamefile).replace('HIST','OUT.nc')
+              else:
+                  self.namefile2 = str(pnamefile)
+              self.type_of_file = 'netcdf'
           else:
               self.type_of_file = 'ASCII_output'
               self.namefile2 = str(pnamefile)
@@ -315,11 +332,6 @@ class MolecularDynamicFile:
       except:
           self.goodFile = False
           print "Error,unable to read this netcdf file "
-          try:
-              QtGui.QMessageBox.critical(None,"Warning","Error,unable to read this netcdf file ")
-          except :
-              pass;
-
 
   def E_kinCalculation(self):
       natom = self.getNatom() 
@@ -333,7 +345,7 @@ class MolecularDynamicFile:
       typat = self.getTypat()
       amu = self.getAmu()
       for typ in typat:
-          self.mass.extend([self.amu_emass*amu[typ-1]])
+          self.mass.extend([self.amu_emass*amu[int(typ-1)]])
 
   def temperature_calculation(self):
       Nbstep = self.getNbStep()-1
@@ -620,7 +632,11 @@ class MolecularDynamicFile:
         
   def getAcell(self,image = 1):
       if self.goodFile:
-          return self.acell[self.ni:self.nf,image-1]    # Temporarily. (ni-1) for start slicing at 0
+          acell = np.zeros(((self.nf-self.ni),image,3))
+          acell[:,image-1,0] = self.rprimd[self.ni:self.nf,image-1,0,0]
+          acell[:,image-1,1] = self.rprimd[self.ni:self.nf,image-1,1,1]
+          acell[:,image-1,2] = self.rprimd[self.ni:self.nf,image-1,2,2]
+          return acell[:,image-1,:] # Temporarily. (ni-1) for start slicing at 0
       else:
           return 0
 
