@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2016 ABINIT group (MT)
+ * Copyright (C) 2015-2018 ABINIT group (MT)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,10 +25,16 @@
 
 #include <stdlib.h>
 
-#if defined HAVE_DFT_LIBXC
+#if defined HAVE_LIBXC
 
 #include "xc.h"
+#include "xc_version.h"
+/* if version before 4 get config file*/
+#if ( XC_MAJOR_VERSION < 4 )
 #include "xc_config.h"
+#else
+#  define FLOAT double
+#endif
 
 /* ===============================================================
  * Get the SINGLE_PRECISION constant
@@ -109,15 +115,40 @@ void xc_func_type_free(XC(func_type) **xc_func)
 
 /* ===============================================================
  * Get properties from a xc_func_info_type pointer
+ *     These accessors where not provided before libXC v3
  * ===============================================================
  */
-char *xc_get_info_name(XC(func_type) *xc_func)
+#if defined XC_MICRO_VERSION
+ /* libXC v3.0 and later */
+char const *xc_get_info_name(XC(func_type) *xc_func)
+ {return xc_func_info_get_name(xc_func->info);}
+int xc_get_info_flags(XC(func_type) *xc_func)
+ {return xc_func_info_get_flags(xc_func->info);}
+int xc_get_info_kind(XC(func_type) *xc_func)
+ {return xc_func_info_get_kind(xc_func->info);}
+char const *xc_get_info_refs(XC(func_type) *xc_func, const int *number)
+ {if (*number>=0&&*number<=4)
+#if ( XC_MAJOR_VERSION < 4 ) 
+   {if (xc_func_info_get_ref(xc_func->info,*number) != NULL)
+    {return xc_func_info_get_ref(xc_func->info,*number);}}
+#else
+/* NB: TODO check if return types are used correctly in version 4. Compilation raises warning about return type of xc_func_info_get_references*/
+   {if (xc_func_info_get_references(xc_func->info,*number) != NULL)
+    {return xc_func_info_get_references(xc_func->info,*number);}}
+#endif
+  else {return NULL;}
+  return NULL;}
+#else
+ /* libXC before v3.0 */
+char const *xc_get_info_name(XC(func_type) *xc_func)
  {return xc_func->info->name;}
-char *xc_get_info_refs(XC(func_type) *xc_func)
- {return xc_func->info->refs;}
 int xc_get_info_flags(XC(func_type) *xc_func)
  {return xc_func->info->flags;}
 int xc_get_info_kind(XC(func_type) *xc_func)
  {return xc_func->info->kind;}
+char const *xc_get_info_refs(XC(func_type) *xc_func, const int *number)
+ {if (*number==0) {return xc_func->info->refs;} else {return NULL;}
+  return NULL;}
+#endif
 
 #endif
