@@ -17,7 +17,6 @@ inp_files = [
 #"si_kpt_band_fft.in",
 #"t_bandfft.in",
 #"t_kpt+spin.in"
-#"t9.in",
 "t01.in",
 "t02.in",
 "t03.in",
@@ -25,6 +24,7 @@ inp_files = [
 "t06.in", 
 "t07.in", 
 "t08.in",
+"t09.in",
 "t21.in",
 "t22.in",
 "-t23.in", # disabled
@@ -49,7 +49,7 @@ inp_files = [
 "t59.in",
 "t60.in",
 "-t61.in", # disabled for now
-"-t62.in", # disabled for now
+"t62.in",
 "t71.in",
 "t72.in",
 "t73.in",
@@ -61,5 +61,12 @@ inp_files = [
 "t92.in",
 "t93.in",
 "t94.in",
-#"-t99.in", # MPI-IO, not tested here!
+"t95.in",
+"t96.in",
+"t97.in",
+"t98.in",
+"t99.in",
+"t100.in",
+"t101.in",
+"t102.in"
 ]
