@@ -15,9 +15,11 @@ subsuites = [
 "bs",
 "gw1",
 "gw2",
-"ldau",
+"dftu",
+"nuc",
 "paw1",
 "paw2",
+"positron",
 "spin",
 "tddft",
 "udet",
@@ -56,6 +58,10 @@ inp_files = [
 "tbs_3.in",
 "tbs_4.in",
 #"tbs_5.in",  # Template file (not used)
+"tdftu_1.in",
+"tdftu_2.in",
+"tdftu_3.in",
+"tdftu_4.in",
 "tgw1_1.in",
 "tgw1_2.in",
 "tgw1_3.in",
@@ -69,10 +75,7 @@ inp_files = [
 "tgw2_2.in",
 "tgw2_3.in",
 "tgw2_4.in",
-"tldau_1.in",
-"tldau_2.in",
-"tldau_3.in",
-"tldau_4.in",
+"tnuc_1.in",
 "tpaw1_1.in",
 "tpaw1_2.in",
 "tpaw1_3.in",
@@ -80,6 +83,13 @@ inp_files = [
 "tpaw1_5.in",
 "tpaw2_1.in",
 "tpaw2_2.in",
+"tpositron_1.in",
+"tpositron_2.in",
+"tpositron_3.in",
+"tpositron_4.in",
+"tpositron_5.in",
+"tpositron_6.in",
+"tpositron_7.in",
 "tspin_1.in",
 "tspin_2.in",
 "tspin_3.in",
